Coverage for C:\Users\t590r\Documents\GitHub\suppy\suppy\feasibility\__init__.py: 100%

1"""Module for linear feasibility and split feasibility algorithms."""

2 from suppy.utils import Bounds

3 from ._bands._ams_algorithms import (

4 SequentialAMSHyperslab,

5 SequentialWeightedAMSHyperslab,

6 SimultaneousAMSHyperslab,

7 StringAveragedAMSHyperslab,

8 BlockIterativeAMSHyperslab,

9)

10 from ._bands._arm_algorithms import SequentialARM, SimultaneousARM, StringAveragedARM

11 from ._bands._art3_algorithms import SequentialART3plus

12

13 from ._halfspaces._ams_algorithms import (

14 SequentialAMSHalfspace,

15 SequentialWeightedAMSHalfspace,

16 SimultaneousAMSHalfspace,

17 StringAveragedAMSHalfspace,

18 BlockIterativeAMSHalfspace,

19)

20

21 from ._hyperplanes._ams_algorithms import (

22 SequentialAMSHyperplane,

23 SequentialWeightedAMSHyperplane,

24 SimultaneousAMSHyperplane,

25 StringAveragedAMSHyperplane,

26 BlockIterativeAMSHyperplane,

27)

28

29 from ._split_algorithms import CQAlgorithm, ProductSpaceAlgorithm

30

31 __all__ = [

32 "SequentialAMSHyperslab",

33 "SequentialWeightedAMSHyperslab",

34 "SimultaneousAMSHyperslab",

35 "StringAveragedAMSHyperslab",

36 "BlockIterativeAMSHyperslab",

37 "SequentialAMSHalfspace",

38 "SequentialWeightedAMSHalfspace",

39 "SimultaneousAMSHalfspace",

40 "StringAveragedAMSHalfspace",

41 "BlockIterativeAMSHalfspace",

42 "SequentialAMSHyperplane",

43 "SequentialWeightedAMSHyperplane",

44 "SimultaneousAMSHyperplane",

45 "StringAveragedAMSHyperplane",

46 "BlockIterativeAMSHyperplane",

47 "SequentialARM",

48 "SimultaneousARM",

49 "StringAveragedARM",

50 "SequentialART3plus",

51 "CQAlgorithm",

52 "ProductSpaceAlgorithm",

53]